==============
Imperative API
==============

.. automodule:: plato.imp
   :members: clear, get, show, arrows2D, box, convex_polyhedra,
             convex_spheropolyhedra, disks, disk_unions, ellipsoids,
             lines, mesh, polygons, sphere_points, spheres,
             sphere_unions, spheropolygons, voronoi
